@@ -4,7 +4,7 @@ cancel <- function(P, R.var, R.cond, S) {
     ch <- P$children[[i]]
     if (ch$var %in% R.var) {
       mis <- which(R.var == ch$var)
-      if (setdiff(R.cond[[mis]], ch$cond) == S) {
+      if (identical(setdiff(R.cond[[mis]], ch$cond), S)) {
         ind <- c(ind, i)
       } else {
         ind <- c()
