@@ -1,21 +1,21 @@
 generalize <- function(y, x, Z, D, expr = TRUE, simp = FALSE, steps = FALSE, primes = FALSE, stop_on_nonid = TRUE) {
   d <- length(D)
   z <- length(Z)
-  v <- get.vertex.attribute(D[[1]], "name")
-  s <- v[which(vertex.attributes(D[[1]])$description == "S")]
+  v <- igraph::get.vertex.attribute(D[[1]], "name")
+  s <- v[which(igraph::vertex.attributes(D[[1]])$description == "S")]
   if (length(s) > 0) stop("The causal diagram cannot contain selection variables.")
   if (d != z) stop("Number of available experiments does not match number of domains.")
   if (length(intersect(x, y)) > 0) stop("Sets 'x' and 'y' are not disjoint.")
-  topo <- lapply(D, function(k) topological.sort(observed.graph(k)))
-  topo <- lapply(1:d, function(k) get.vertex.attribute(D[[k]], "name")[topo[[k]]])
+  topo <- lapply(D, function(k) igraph::topological.sort(observed.graph(k)))
+  topo <- lapply(1:d, function(k) igraph::get.vertex.attribute(D[[k]], "name")[topo[[k]]])
   D <- lapply(D, function(k) {
-    if (length(edge.attributes(k)) == 0) {
-      k <- set.edge.attribute(k, "description", 1:length(E(k)), NA)
+    if (length(igraph::edge.attributes(k)) == 0) {
+      k <- igraph::set.edge.attribute(k, "description", 1:length(igraph::E(k)), NA)
     }
     return(k)
   })
   for (i in 1:d) {
-    if (!is.dag(observed.graph(D[[i]]))) {
+    if (!igraph::is.dag(observed.graph(D[[i]]))) {
       if (i > 1) stop("Selection diagram 'D[", i, "]' is not a DAG.")
       else stop("Causal diagram 'D[", i, "]' is not a DAG.")
     }
