@@ -6,14 +6,13 @@ idc <- function(y, x, z, P, G, G.obs, v, topo, tree, prune) {
   offset <- (prune) * 2
   from <- NULL
   G.xz <- unobserved.graph(G)
-  edges.to.x <- E(G.xz)[to(x)]
-  edges.from.z <- E(G.xz)[from(z)]
-  G.xz <- subgraph.edges(G.xz, E(G.xz)[setdiff(E(G.xz), union(edges.to.x, edges.from.z))], delete.vertices = FALSE)
-  A <- as.matrix(get.adjacency(G.xz))
+  edges.to.x <- igraph::E(G.xz)[to(x)]
+  edges.from.z <- igraph::E(G.xz)[from(z)]
+  G.xz <- igraph::subgraph.edges(G.xz, igraph::E(G.xz)[setdiff(igraph::E(G.xz), union(edges.to.x, edges.from.z))], delete.vertices = FALSE)
   nxt <- list()
   for (node in z) {
     cond <- setdiff(z, node)
-    if (dSep(A, y, node, union(x, cond))) {
+    if (wrap.dSep(G.xz, y, node, union(x, cond))) {
       tree$call$line <- 9 + offset
       tree$call$z.prime <- node
       nxt <- idc(y, union(x, node) %ts% topo, cond, P, G, G.obs, v, topo, list(), prune)
